This crate provides nix language support for the tree-sitter parsing library.
Typically, you will use the language function to add this language to a tree-sitter Parser, and then use the parser to parse some code:
let code = "";
let mut parser = tree_sitter::Parser::new();
parser.set_language(&npezza93_tree_sitter_nix::LANGUAGE.into()).expect("Error loading nix grammar");
let tree = parser.parse(code, None).unwrap();Constants
- HIGHLIGHTS_
QUERY - LANGUAGE
- Get the tree-sitter Language for this grammar.
- NODE_
TYPES - The content of the
node-types.jsonfile for this grammar.